@@ -32,12 +32,12 @@
                                  MCF5282_UART_USR_PE | \
                                  MCF5282_UART_USR_OE )
 
-static int IntUartPollWrite(int minor, const char *buf, int len);
-static int IntUartInterruptWrite (int minor, const char *buf, int len);
+static ssize_t IntUartPollWrite(int minor, const char *buf, size_t len);
+static ssize_t IntUartInterruptWrite (int minor, const char *buf, size_t len);
 
 static void
 _BSP_null_char( char c )
-{ 
+{
 	int level;
 
     if (c == '\n')
@@ -76,45 +76,6 @@ struct IntUartInfoStruct
 
 struct IntUartInfoStruct IntUartInfo[MAX_UART_INFO];
 
-static int GetBaud( int baudHandle )
-{
-	int baud = 9600;
-	switch ( baudHandle )
-	{
-		case B0:
-			baud = (int)0;
-			break;
-		case B1200:
-			baud = (int)1200;
-			break;
-		case B2400:
-			baud = (int)2400;
-			break;
-		case B4800:
-			baud = (int)4800;
-			break;
-		case B9600:
-			baud = (int)9600;
-			break;
-		case B19200:
-			baud = (int)19200;
-			break;
-		case B38400:
-			baud = (int)38400;
-			break;
-		case B57600:
-			baud = (int)57600;
-			break;
-		case B115200:
-			baud = (int)115200;
-			break;
-/*		case B576000:
-			baud = (int)576000; */
-			break;
-	}
-	return ( baud );
-}
-
 /***************************************************************************
    Function : IntUartSet
 
@@ -208,7 +169,7 @@ IntUartSet(int minor, int baud, int databits, int parity, int stopbits, int hwfl
    Description : This provides the hardware-dependent portion of tcsetattr().
    value and sets it. At the moment this just sets the baud rate.
 
-   Note: The highest baudrate is 115200 as this stays within 
+   Note: The highest baudrate is 115200 as this stays within
    an error of +/- 5% at 25MHz processor clock
  ***************************************************************************/
 static int
@@ -226,7 +187,7 @@ IntUartSetAttributes(int minor, const struct termios *t)
 	if ( t != (const struct termios *)0 )
 	{
 		/* determine baud rate index */
-		baud = GetBaud( t->c_cflag & CBAUD );
+  		baud = rtems_termios_baud_to_number(t->c_cflag & CBAUD);
 
 		/* determine data bits */
 		switch ( t->c_cflag & CSIZE )
@@ -440,13 +401,13 @@ IntUartInitialize(void)
 /***************************************************************************
    Function : IntUartInterruptWrite
 
-   Description : This writes a single character to the appropriate uart 
+   Description : This writes a single character to the appropriate uart
    channel. This is either called during an interrupt or in the user's task
-   to initiate a transmit sequence. Calling this routine enables Tx 
+   to initiate a transmit sequence. Calling this routine enables Tx
    interrupts.
  ***************************************************************************/
-static int
-IntUartInterruptWrite (int minor, const char *buf, int len)
+static ssize_t
+IntUartInterruptWrite (int minor, const char *buf, size_t len)
 {
 	int level;
 
@@ -460,7 +421,7 @@ IntUartInterruptWrite (int minor, const char *buf, int len)
 	MCF5282_UART_UIMR(minor) = IntUartInfo[minor].uimr;
 
 	rtems_interrupt_enable(level);
-	return( 0 );
+	return 0;
 }
 
 /***************************************************************************
@@ -486,9 +447,10 @@ IntUartInterruptOpen(int major, int minor, void *arg)
 		MCF5282_GPIO_PUAPAR |= MCF5282_GPIO_PUAPAR_PUAPA3|MCF5282_GPIO_PUAPAR_PUAPA2;
 		break;
 	case 2:
-		MCF5282_GPIO_PASPAR = MCF5282_GPIO_PASPAR
-             & ~(MCF5282_GPIO_PASPAR_PASPA3(3)|MCF5282_GPIO_PASPAR_PASPA2(3))
-             |  (MCF5282_GPIO_PASPAR_PASPA3(2)|MCF5282_GPIO_PASPAR_PASPA2(2));
+		MCF5282_GPIO_PASPAR = 
+		  (MCF5282_GPIO_PASPAR
+		   & ~(MCF5282_GPIO_PASPAR_PASPA3(3)|MCF5282_GPIO_PASPAR_PASPA2(3)))
+		  |  (MCF5282_GPIO_PASPAR_PASPA3(2)|MCF5282_GPIO_PASPAR_PASPA2(2));
 		break;
 	}
 	rtems_interrupt_enable(level);
@@ -568,7 +530,7 @@ IntUartTaskRead(int minor)
 	/* copy data into local buffer from rx buffer */
 	while ( ( index < count ) && ( index < RX_BUFFER_SIZE ) )
 	{
-		/* copy data byte */ 
+		/* copy data byte */
 		buffer[index] = info->rx_buffer[info->rx_out];
 		index++;
 
@@ -595,7 +557,7 @@ IntUartTaskRead(int minor)
 /***************************************************************************
    Function : IntUartPollRead
 
-   Description : This reads a character from the internal uart. It returns 
+   Description : This reads a character from the internal uart. It returns
    to the caller without blocking if not character is waiting.
  ***************************************************************************/
 static int
@@ -611,13 +573,14 @@ IntUartPollRead (int minor)
 /***************************************************************************
    Function : IntUartPollWrite
 
-   Description : This writes out each character in the buffer to the 
-   appropriate internal uart channel waiting till each one is sucessfully 
+   Description : This writes out each character in the buffer to the
+   appropriate internal uart channel waiting till each one is sucessfully
    transmitted.
  ***************************************************************************/
-static int
-IntUartPollWrite (int minor, const char *buf, int len)
+static ssize_t
+IntUartPollWrite (int minor, const char *buf, size_t len)
 {
+	size_t retval = len;
 	/* loop over buffer */
 	while ( len-- )
 	{
@@ -627,21 +590,9 @@ IntUartPollWrite (int minor, const char *buf, int len)
 		/* transmit data byte */
 		MCF5282_UART_UTB(minor) = *buf++;
 	}
-	return(0);
+	return retval;
 }
 
-/***************************************************************************
-   Function : console_reserve_resources
-
-   Description : This reserves resources consumed by this driver. It passes
-   the request on to the termios subsystem.
- ***************************************************************************/
-void console_reserve_resources( rtems_configuration_table *configuration )
-{
-	rtems_termios_reserve_resources (configuration, 1);
-}
-
-
 /***************************************************************************
    Function : console_initialize
 
@@ -662,7 +613,7 @@ rtems_device_driver console_initialize(
 	/* set io modes for the different channels and initialize device */
 	for ( chan = 0; chan < MAX_UART_INFO; chan++ )
 		IntUartInfo[chan].iomode = TERMIOS_IRQ_DRIVEN;
-	IntUartInitialize(); 
+	IntUartInitialize();
 
 	/* Register the console port */
 	status = rtems_io_register_name ("/dev/console", major, CONSOLE_PORT);
@@ -700,7 +651,7 @@ rtems_device_driver console_initialize(
 /***************************************************************************
    Function : console_open
 
-   Description : This actually opens the device depending on the minor 
+   Description : This actually opens the device depending on the minor
    number set during initialisation. The device specific access routines are
    passed to termios when the devices is opened depending on whether it is
    polled or not.
@@ -841,3 +792,6 @@ void DEBUG_OUTNUM(int i)
     for (n = 28 ; n >= 0 ; n -= 4)
         DEBUG_OUTCHAR(map[(i >> n) & 0xF]);
 }
+
+BSP_polling_getchar_function_type       BSP_poll_char = NULL;
+
