@@ -598,6 +598,25 @@ static void clr_int_logs(struct irq_log_list *logs){
 	}
 }
 
+unsigned short b1553brm_rt_cmd_legalize[16] = {
+	0,
+	0,
+	0,
+	0,
+	0,
+	0,
+	0xffff,
+	0xffff,
+	0xffff,
+	0xfffd,
+	0xfe01,
+	0xfff2,
+	0xffff,
+	0xfffd,
+	0xfe05,
+	0xffff,
+};
+
 static rtems_device_driver rt_init(brm_priv *brm) {
 	unsigned int i;
 
@@ -635,9 +654,9 @@ static rtems_device_driver rt_init(brm_priv *brm) {
 		
 	clr_int_logs(brm->irq_log);
 
-	/* Legalize all commands */
+	/* Initialize the Legalize register with standard values */
 	for (i = 0; i < 16; i++) {
-		brm->regs->rt_cmd_leg[i] = 0;
+		brm->regs->rt_cmd_leg[i] = b1553brm_rt_cmd_legalize[i];
 	}
 
 	/* Init descriptor table 
@@ -701,14 +720,14 @@ static rtems_device_driver bc_init(brm_priv *brm){
 	if ( brm->rt_event )
 		free(brm->rt_event);
 	brm->rt_event = NULL;
-	
+
 	brm->bcmem = (void *)brm->mem;
 	brm->rtmem = NULL;
 	brm->irq_log = (struct irq_log_list *)&brm->bcmem->irq_logs[0];
-	
+
 	brm->head = brm->tail = 0;
 	brm->rx_blocking = brm->tx_blocking = 1;
-	
+
 	brm->regs->ctrl	  = 0x0006;  /* ping pong enable and enable interrupt log */
 	brm->regs->oper	  = 0x0800;  /* configure as BC */
 	brm->regs->imask	 = BRM_EOL_IRQ|BRM_BC_ILLCMD_IRQ|BRM_ILLOP_IRQ|BRM_DMAF_IRQ|BRM_WRAPF_IRQ|BRM_MERR_IRQ;
@@ -948,7 +967,21 @@ static rtems_device_driver brm_write(rtems_device_major_number major, rtems_devi
 
 				/* No room in transmission buffer */ 
 				if (brm->tx_blocking && count == 0) {
-					rtems_semaphore_obtain(brm->tx_sem, RTEMS_WAIT, RTEMS_NO_TIMEOUT);
+					if (rtems_semaphore_obtain(brm->tx_sem,
+					    RTEMS_WAIT, RTEMS_NO_TIMEOUT) !=
+					    RTEMS_SUCCESSFUL) {
+						return RTEMS_INTERNAL_ERROR;
+					}
+					/* check if buffers available now.
+					 * Note that the interrupt may have
+					 * woken us even when there is not enough
+					 * room for another message, reasons:
+					 *  - a smaller message than this was
+					 *    previously sent, our message
+					 *    still does not fit.
+					 *  - IRQ stems from a different SA
+					 */
+					continue;
 				} else if ( count > 0 ) {
 					/* return the number of messages sent so far */
 					break;
