@@ -1,5 +1,12 @@
 /*
- *  $Id: key.c,v 1.13 2004/04/16 10:01:03 ralf Exp $
+ *  COPYRIGHT (c) 1989-2008.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -10,8 +17,10 @@
 #include <limits.h>
 #include <pthread.h>
 #include <string.h>
+#include <limits.h>
 
 #include <rtems/system.h>
+#include <rtems/config.h>
 #include <rtems/score/thread.h>
 #include <rtems/score/wkspace.h>
 #include <rtems/posix/key.h>
@@ -22,24 +31,27 @@
  *  DESCRIPTION:
  *
  *  This routine performs the initialization necessary for this manager.
+ *
+ *  Input parameters:   NONE
+ *
+ *  Output parameters:  NONE
  */
 
-void _POSIX_Key_Manager_initialization(
-  uint32_t   maximum_keys
-)
+void _POSIX_Key_Manager_initialization(void)
 {
   _Objects_Initialize_information(
     &_POSIX_Keys_Information,   /* object information table */
     OBJECTS_POSIX_API,          /* object API */
     OBJECTS_POSIX_KEYS,         /* object class */
-    maximum_keys,               /* maximum objects of this class */
+    Configuration_POSIX_API.maximum_keys,
+                                /* maximum objects of this class */
     sizeof( POSIX_Keys_Control ),
                                 /* size of this object's control block */
-    FALSE,                      /* TRUE if names for this object are strings */
-    0                           /* maximum length of each object's name */
+    true,                       /* true if names for this object are strings */
+    _POSIX_PATH_MAX             /* maximum length of each object's name */
 #if defined(RTEMS_MULTIPROCESSING)
     ,
-    FALSE,                      /* TRUE if this is a global object class */
+    false,                      /* true if this is a global object class */
     NULL                        /* Proxy extraction support callout */
 #endif
   );
