@@ -1,13 +1,21 @@
 /*
  *  3.4.3 Delay Process Execution, P1003.1b-1993, p. 81
  *
- *  $Id: sleep.c,v 1.3 2007/04/02 18:23:59 joel Exp $
+ *  COPYRIGHT (c) 1989-2007.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#ifndef HAVE_SLEEP
 #include <time.h>
 #include <unistd.h>
 
@@ -28,3 +36,5 @@ unsigned int sleep(
 
   return tm.tv_sec;       /* seconds remaining */
 }
+
+#endif
