@@ -9,7 +9,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: regionident.c,v 1.8 2005/01/18 09:03:44 ralf Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -44,15 +44,15 @@
  */
 
 rtems_status_code rtems_region_ident(
-  rtems_name    name,
-  Objects_Id   *id
+  rtems_name  name,
+  rtems_id   *id
 )
 {
   Objects_Name_or_id_lookup_errors  status;
 
-  status = _Objects_Name_to_id(
+  status = _Objects_Name_to_id_u32(
     &_Region_Information,
-    (Objects_Name) name,
+    name,
     OBJECTS_SEARCH_LOCAL_NODE,
     id
   );
