@@ -1,4 +1,12 @@
 /**
+ * @file
+ *
+ * @ingroup ScoreProtHeap
+ *
+ * @brief Protected Heap Handler implementation.
+ */
+
+/*
  *  COPYRIGHT (c) 1989-2007.
  *  On-Line Applications Research Corporation (OAR).
  *
@@ -6,7 +14,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: pheapgetblocksize.c,v 1.1.2.1 2007/12/11 23:44:29 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -16,16 +24,16 @@
 #include <rtems/system.h>
 #include <rtems/score/protectedheap.h>
 
-boolean _Protected_heap_Get_block_size(
+bool _Protected_heap_Get_block_size(
   Heap_Control        *the_heap,
   void                *starting_address,
-  size_t              *size
+  uintptr_t           *size
 )
 {
-  boolean status;
+  bool status;
 
   _RTEMS_Lock_allocator();
-    status = _Heap_Size_of_user_area( the_heap, starting_address, size );
+    status = _Heap_Size_of_alloc_area( the_heap, starting_address, size );
   _RTEMS_Unlock_allocator();
   return status;
 }
