@@ -3,14 +3,14 @@
  *  This include file contains information that is included in every
  *  function in the test set.
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2008.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: system.h,v 1.9 2004/04/15 13:22:06 ralf Exp $
+ *  $Id$
  */
 
 #include <tmacros.h>
@@ -19,11 +19,13 @@
 /* functions */
 
 void ITRON_Init( void );
-void Dormant_task();
-void Non_Dormant_task();
+void Dormant_task(void);
+void Non_Dormant_task(void);
 
 /* configuration information */
 
+/* NOTICE: the clock driver is explicitly disabled */
+#define CONFIGURE_APPLICATION_DOES_NOT_NEED_CLOCK_DRIVER
 #define CONFIGURE_APPLICATION_NEEDS_CONSOLE_DRIVER
 
 #define CONFIGURE_MAXIMUM_ITRON_TASKS      5
