@@ -6,7 +6,14 @@
  *  The defined behavior is a seek() followed by a write() extends the file
  *  and zero fills the new length part.
  *
- *  $Id: test_extend.c,v 1.3 2004/04/16 09:23:25 ralf Exp $
+ *  COPYRIGHT (c) 1989-2009.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
  */
 
 #include <stdio.h>
@@ -19,8 +26,6 @@
 #include <string.h>
 #include <ctype.h>
 
-#include <assert.h>
-
 #include <pmacros.h>
 
 /*
@@ -43,7 +48,7 @@ void test_extend(
   }
 
   status = lseek( fd, offset - 1, SEEK_SET );
-  assert( status != -1 );
+  rtems_test_assert( status != -1 );
 
   status = write( fd, &c, 1 );
   if ( status == -1 ) {
@@ -58,5 +63,5 @@ void test_extend(
   }
 
   status = close( fd );
-  assert( !status );
+  rtems_test_assert( !status );
 }
