@@ -8,19 +8,19 @@
  *
  *  Output parameters:  NONE
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2009.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: tdelete.c,v 1.11 2007/05/11 19:44:27 joel Exp $
+ *  $Id$
  */
 
 #include "system.h"
 
-rtems_extension Task_delete_extension(
+void Task_delete_extension(
   rtems_tcb *running_task,
   rtems_tcb *deleted_task
 )
@@ -30,21 +30,27 @@ rtems_extension Task_delete_extension(
 
   if ( task_number( running_task->Object.id ) > 0 ) {
     name = Task_name[ task_number( running_task->Object.id ) ];
-    sprintf( line, "TASK_DELETE - %c%c%c%c TASK_DELETE",
-      (name >> 24) & 0xff,
-      (name >> 16) & 0xff,
-      (name >> 8) & 0xff,
-      name & 0xff
+    sprintf( line, "TASK_DELETE - %c%c%c%c TASK_DELETE ",
+      (char)((name >> 24) & 0xff),
+      (char)((name >> 16) & 0xff),
+      (char)((name >> 8) & 0xff),
+      (char)(name & 0xff)
     );
     buffered_io_add_string( line );
   }
   if ( task_number( deleted_task->Object.id ) > 0 ) {
     name = Task_name[ task_number( deleted_task->Object.id ) ];
+/*
+ * FIXME: There should be a public function to
+ * convert numeric rtems_names into char arrays
+ * c.f. rtems_name_to_characters() in rtems/rtems/support.inl
+ * but it's private.
+ */
     sprintf( line, "deleting - %c%c%c%c\n",
-      (name >> 24) & 0xff,
-      (name >> 16) & 0xff,
-      (name >> 8) & 0xff,
-      name & 0xff
+      (char)((name >> 24) & 0xff),
+      (char)((name >> 16) & 0xff),
+      (char)((name >> 8) & 0xff),
+      (char)(name & 0xff)
     );
     buffered_io_add_string( line );
   }
